Common, neocortex-v5 and neocortex-v6 mod files are merged. Below are the sources.

Common mods repository: hpc/sim/models/common.git
Common mods git hash: bfe26c3d

Neocortex mods repository: hpc/sim/models/neocortex.git
Neocortex mods git hash: 7feb8d9

[Update]
The mechanisms for the Hippocampus are added and any conflicts that arose are addressed by favoring the modifications intended for the neocortex. Please note, these modifications are solely intended for software testing and verification purposes. They are not designed or recommended for conducting scientific simulations.
